@@ -1,25 +1,25 @@
 from pydantic import BaseModel, ValidationError
-from typing import Union, Optional, List
+from typing import Union, Optional, List, Any
 
 from moloni.base.client import MoloniBaseClient
 from moloni.base.helpers import endpoint, fill_query_params, validate_data
 
 
 class Suppliers(BaseModel):
-    cost_price: Optional[Union[str, int]]
-    supplier_id: Optional[Union[str, int]]
+    cost_price: Optional[Any] = None
+    supplier_id: Optional[Any] = None
 
 
 class Taxes(BaseModel):
-    cumulative: Optional[Union[str, int]]
-    order: Optional[Union[str, int]]
-    tax_id: Optional[Union[str, int]]
-    value: Optional[Union[str, int]]
+    cumulative: Optional[Any] = None
+    order: Optional[Any] = None
+    tax_id: Optional[Any] = None
+    value: Optional[Any] = None
 
 
 class Warehouses(BaseModel):
-    stock: Optional[Union[str, int]]
-    warehouse_id: Optional[Union[str, int]]
+    stock: Optional[Any] = None
+    warehouse_id: Optional[Any] = None
 
 
 class SubscriptionGetOneModel(BaseModel):
